==> YFrake-0.1.3.tar.gz: YFrake-0.1.3/yfrake/server/server.py <==
# ==================================================================================== #
#    server.py - This file is part of the YFrake package.                              #
# ------------------------------------------------------------------------------------ #
#                                                                                      #
#    MIT License                                                                       #
#                                                                                      #
#    Copyright (c) 2022 Mattias Aabmets                                                #
#                                                                                      #
#    Permission is hereby granted, free of charge, to any person obtaining a copy      #
#    of this software and associated documentation files (the "Software"), to deal     #
#    in the Software without restriction, including without limitation the rights      #
#    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell         #
#    copies of the Software, and to permit persons to whom the Software is             #
#    furnished to do so, subject to the following conditions:                          #
#                                                                                      #
#    The above copyright notice and this permission notice shall be included in all    #
#    copies or substantial portions of the Software.                                   #
#                                                                                      #
#    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR        #
#    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,          #
#    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE       #
#    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER            #
#    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,     #
#    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE     #
#    SOFTWARE.                                                                         #
#                                                                                      #
# ==================================================================================== #
from . import runner, utils
import subprocess
import psutil
import sys


# ==================================================================================== #
class Server:
    """
    This class contains methods to control
    the YFrake server programmatically.
    """
    _server: subprocess.Popen = None
    _is_running: bool = False

    # ---------------------------------------------------------------------------------- #
    @classmethod
    def is_running(cls) -> bool:
        if cls._server is not None:
            cls._is_running = cls._server.poll() is None
        return cls._is_running

    # ---------------------------------------------------------------------------------- #
    @classmethod
    def start(cls, host: str = None, port: int = None) -> None:
        if not cls.is_running():
            config = dict(host=host, port=str(port))
            if not host or not port:
                config = utils.get_server_config()
            cls._server = subprocess.Popen([
                sys.executable, runner.__file__,
                '--host', config['host'],
                '--port', config['port']
            ])

    # ---------------------------------------------------------------------------------- #
    @classmethod
    def stop(cls) -> None:
        if cls.is_running():
            try:
                parent = psutil.Process(cls._server.pid)
                children = parent.children(recursive=True)
                for child in children:
                    child.kill()
                parent.kill()
            except psutil.NoSuchProcess:
                return

==> YFrake-0.2.0.tar.gz: YFrake-0.2.0/yfrake/server/server.py <==
# ==================================================================================== #
#    server.py - This file is part of the YFrake package.                              #
# ------------------------------------------------------------------------------------ #
#                                                                                      #
#    MIT License                                                                       #
#                                                                                      #
#    Copyright (c) 2022 Mattias Aabmets                                                #
#                                                                                      #
#    Permission is hereby granted, free of charge, to any person obtaining a copy      #
#    of this software and associated documentation files (the "Software"), to deal     #
#    in the Software without restriction, including without limitation the rights      #
#    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell         #
#    copies of the Software, and to permit persons to whom the Software is             #
#    furnished to do so, subject to the following conditions:                          #
#                                                                                      #
#    The above copyright notice and this permission notice shall be included in all    #
#    copies or substantial portions of the Software.                                   #
#                                                                                      #
#    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR        #
#    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,          #
#    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE       #
#    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER            #
#    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,     #
#    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE     #
#    SOFTWARE.                                                                         #
#                                                                                      #
# ==================================================================================== #
from . import runner, utils
import subprocess
import psutil
import sys


# ==================================================================================== #
class Server:
    """
    This class contains methods to control
    the YFrake server programmatically.
    """
    _server: subprocess.Popen = None
    _is_running: bool = False

    # ---------------------------------------------------------------------------------- #
    @classmethod
    def is_running(cls) -> bool:
        if cls._server is not None:
            cls._is_running = cls._server.poll() is None
        return cls._is_running

    # ---------------------------------------------------------------------------------- #
    @classmethod
    def start(cls, **kwargs) -> None:
        if not cls.is_running():
            config = dict()
            defaults = utils.get_server_config()
            for opt in ['host', 'port', 'limit', 'timeout', 'backlog']:
                config[opt] = str(kwargs.get(opt, defaults[opt]))
            cls._server = subprocess.Popen(
                [
                    sys.executable, runner.__file__,
                    '--host', config['host'],
                    '--port', config['port'],
                    '--limit', config['limit'],
                    '--timeout', config['timeout'],
                    '--backlog', config['backlog']
                ]
            )

    # ---------------------------------------------------------------------------------- #
    @classmethod
    def stop(cls) -> None:
        if cls.is_running():
            try:
                parent = psutil.Process(cls._server.pid)
                children = parent.children(recursive=True)
                for child in children:
                    child.kill()
                parent.kill()
            except psutil.NoSuchProcess:
                return
